#!/bin/sh
# -*- coding: utf-8 -*-
#
# auto-compile script for upTeX
# upTeX をコンパイルするためのスクリプト
#
# This script automatically compiles upTeX.
# Run this script instead of "make all" on ptetex3.
# After that, do "make fonty" and "make install".
# upTeX を完全自動でコンパイルします。
# ptetex3 の "make all" の代わりに、このスクリプトを実行します。
# その後 "make fonty" や "make install" が必要です。
#
# Put the files prior to compile.
# 以下のようにファイルを置いておきます。
#
# [In the directory as same as in that teTeX-{src,texmf}-*.tar.gz is ;
#  teTeX-{src,texmf}-*.tar.gz と同じディレクトリ]
#    uptex_font-0.22.tar.gz
#    cbfonts.zip   (optionally; もしあれば)
#    cm-super.zip  (optionally; もしあれば)
#    unicode.zip   (optionally; もしあれば)
#    dvi2tty51.tgz      (optionally; copy from jdvi2tty_src/SOURCES/)
#    dvi2tty-5.1.patch  (optionally; copy from jdvi2tty_src/SOURCES/)
#
# [In ptetex3-20YYMMDD/ ;
#  展開した ptetex3-20YYMMDD/ の下]
#    0uptex.sh     (This script; このスクリプト)
#    ptetex3-*uptex_src*.patch
#    ptetex3-*uptex_texmf*.patch
#    xdvi_cfg*uptex*.patch
#    utfsrc*uptex*.patch
#    otfstable-uptex-*.tar.gz
#    updvi2tty-*.patch
#    5macro_uptex.sh
#    6babel_uptex.sh
#    convbkmk.rb
#    ptex-src-3.1.10-3.1.11.patch

. ./common.sh

# cpatchl() is cpatch() with -l option
# usage: cpatchl hoge.patch strip-num dist-dir
cpatchl() {
    echo "[patching]   $1"
    if test ! -f "$1"; then echo "'$1' doesn't exist"; exit 1; fi
    cat "$1" | $PATCH -p$2 -s -l -d "$3" || exit 1
}

if test "$JAPANESE" != "traditional"; then
    echo "$JAPANESE should be 'traditional'."
    exit 1
fi

## Expand teTeX + pTeX
## teTeX + pTeX の展開
unset TEXMFMAIN
make distclean check x || exit

## Apply the patch
## patch 当て
cpatchl ptex-src-3.1.10-3.1.11.patch 1 $SRC/texk/web2c/ptex

## Prepare upTeX patch
## upTeX patch を当てる前の準備
$CP -rp $SRC/texk/web2c/ptex \
        $SRC/texk/web2c/uptexdir || exit
mv      $SRC/texk/web2c/uptexdir/ptex-base.ch \
        $SRC/texk/web2c/uptexdir/uptex-base.ch || exit
mv      $SRC/texk/web2c/uptexdir/tftopl.ch \
        $SRC/texk/web2c/uptexdir/uptftopl.ch || exit
mv      $SRC/texk/web2c/uptexdir/pltotf.ch \
        $SRC/texk/web2c/uptexdir/uppltotf.ch || exit
mv      $SRC/texk/web2c/uptexdir/pdvitype.ch \
        $SRC/texk/web2c/uptexdir/updvitype.ch || exit
mv      $SRC/texk/web2c/uptexdir/jbibtex.ch \
        $SRC/texk/web2c/uptexdir/upjbibtex.ch || exit
mv      $SRC/texk/web2c/uptexdir/ptexextra.h \
        $SRC/texk/web2c/uptexdir/ptexextra.in || exit
mv      $SRC/texk/web2c/uptexdir/jmpost/pdvitomp.ch \
        $SRC/texk/web2c/uptexdir/jmpost/updvitomp.ch || exit
mv      $SRC/texk/web2c/uptexdir/jmpost/pmakempx \
        $SRC/texk/web2c/uptexdir/jmpost/upmakempx || exit
mv      $SRC/texk/web2c/uptexdir/jmpost/jmp.ch \
        $SRC/texk/web2c/uptexdir/jmpost/upjmp.ch || exit
$CP     $SRC/texk/web2c/omegaware/ovp2ovf.web \
        $SRC/texk/web2c/omegaware/upovp2ovf.web || exit
$CP     $SRC/texk/web2c/omegaware/ovp2ovf.ch \
        $SRC/texk/web2c/omegaware/upovp2ovf.ch || exit

echo

## Exit when making patches
## patch 生成に利用する場合はここでおしまい
if test "$1" = "orig"; then
    $RM -r $TMP_PREFIX.orig
    mv $TMP_PREFIX $TMP_PREFIX.orig
    exit
fi

## Apply the patches
## patch 当て
cpatch ptetex3-*uptex_texmf*.patch 3 $TEXMF
cpatch ptetex3-*uptex_src*.patch   2 $SRC
#cpatch extra.patch                2 $SRC

## Exit when making patches
## patch 生成に利用する場合はここでおしまい
if test "$1" = "patch"; then
    exit
fi


## for updvi2tty
if test -f $SRC_DIR/dvi2tty51.tgz & test -f $SRC_DIR/dvi2tty-5.1.patch; then
  tarx $SRC_DIR/dvi2tty51.tgz $SRC/texk
  mv $SRC/texk/dvi2tty* $SRC/texk/updvi2tty || exit
  cpatch $SRC_DIR/dvi2tty-5.1.patch 1 $SRC/texk/updvi2tty
  mv $SRC/texk/updvi2tty/Makefile $SRC/texk/updvi2tty/Makefile.orig || exit
  cpatch updvi2tty-*.patch 1 $SRC/texk/updvi2tty
fi

## Expand binary fonts
## コンパイル済みフォントの展開
tarx $SRC_DIR/uptex_font-0.22.tar.gz $TEXMF || exit
$RM -r $TEXMF/fonts/*uptex* || exit

## cbfonts
if test -f $SRC_DIR/cbfonts.zip; then
  UPTEX_TEXMF_DIR=$TMP_PREFIX/share/texmf-dist
  FONT_DIR=$UPTEX_TEXMF_DIR/fonts
  TEX_DIR=$UPTEX_TEXMF_DIR/tex
  unzip $SRC_DIR/cbfonts.zip -d $PTETEX_TMP
  for d in source tfm type1; do
    $MKDIR $FONT_DIR/$d/cbgreek
    mv $PTETEX_TMP/cbfonts/fonts/$d/cbgreek/* $FONT_DIR/$d/cbgreek
    chmod 644 $FONT_DIR/$d/cbgreek/*
  done
  for d in enc map; do
    $MKDIR $FONT_DIR/$d/dvips/cbgreek
    mv $PTETEX_TMP/cbfonts/fonts/$d/* $FONT_DIR/$d/dvips/cbgreek
    chmod 644 $FONT_DIR/$d/dvips/cbgreek/*
  done
  $MKDIR $TEX_DIR/latex/cbgreek
  mv $PTETEX_TMP/cbfonts/tex/latex/cbgreek/* $TEX_DIR/latex/cbgreek
  chmod 644 $TEX_DIR/latex/cbgreek/*
  $RM -r $PTETEX_TMP/cbfonts
cat <<EOF >> $TMP_PREFIX/share/texmf/web2c/updmap.cfg || exit

# cbfonts
MixedMap cbgreek-full.map
EOF
fi

## cm-super
if test -f $SRC_DIR/cm-super.zip; then
  UPTEX_TEXMF_DIR=$TMP_PREFIX/share/texmf-dist
  FONT_DIR=$UPTEX_TEXMF_DIR/fonts
  unzip $SRC_DIR/cm-super.zip -d $PTETEX_TMP
  $MKDIR $FONT_DIR/type1/cm-super
  mv $PTETEX_TMP/cm-super/pfb $FONT_DIR/type1/cm-super
  $MKDIR $FONT_DIR/map/dvips/cm-super
  mv $PTETEX_TMP/cm-super/dvips/*.map $FONT_DIR/map/dvips/cm-super
  $MKDIR $FONT_DIR/enc/dvips/cm-super
  mv $PTETEX_TMP/cm-super/dvips/*.enc $FONT_DIR/enc/dvips/cm-super
  $MKDIR $UPTEX_TEXMF_DIR/tex/latex/cm-super
  mv $PTETEX_TMP/cm-super/*.sty $UPTEX_TEXMF_DIR/tex/latex/cm-super
  $RM -r $PTETEX_TMP/cm-super
cat <<EOF >> $TMP_PREFIX/share/texmf/web2c/updmap.cfg || exit

# cm-super
Map cm-super-t1.map
Map cm-super-ts1.map
Map cm-super-t2a.map
Map cm-super-t2b.map
Map cm-super-t2c.map
Map cm-super-x2.map
EOF
fi

## unicode.zip
if test -f $SRC_DIR/unicode.zip; then
  UPTEX_TEXMF_DIR=$TMP_PREFIX/share/texmf-dist
  UNICODE_PACKAGE_DIR=$UPTEX_TEXMF_DIR/tex/latex/unicode
  unzip $SRC_DIR/unicode.zip -d $PTETEX_TMP
  $MKDIR $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/*.sty $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/*.def $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/data $UNICODE_PACKAGE_DIR
  mv $PTETEX_TMP/unicode/contrib $UNICODE_PACKAGE_DIR
  $RM -r $PTETEX_TMP/unicode
fi

## Do compile
## コンパイル
DATE=`date +%m%d-%H%M`
make c 2>&1 | tee log-$DATE
./5macro_uptex.sh clean default utf 2>&1 | tee -a log-$DATE
if test -f $TEXMF/xdvi/xdvi.cfg ; then
  cpatch xdvi_cfg*uptex*.patch 1 $TEXMF/xdvi
fi
cpatch utfsrc*uptex*.patch 1 $TEXMF/packages/utfsrc

## otf package   Comment out if you do not need it
## otf package   不要ならコメントアウトする
./5macro_uptex.sh otf 2>&1 | tee -a log-$DATE

## babel         Comment out if you do not need it
## babel         不要ならコメントアウトする
./6babel_uptex.sh 2>&1 | tee -a log-$DATE

## convbkmk     Comment out if you do not need it
## convbkmk     不要ならコメントアウトする
$CP -p convbkmk.rb $TMP_PREFIX/bin || exit


cat <<EOF
ptetex3 + upTeX make succeeded."
Your next steps are following.
  make font (or 'fonty')
  make test
  make install (by root)
EOF


## The following prepares borne sh script of setting environment 
##   on $TMP_PREFIX directory for test
## If you use it, comment out the "exit"
## $TMP_PREFIX でテストするときのための環境変数を設定する
##   borne shスクリプトを作成する。
## 使用するならこの "exit" をコメントアウトする。
exit

cat <<EOF > $TMP_PREFIX/bin/settexenv
TMPDIR=$TMP_PREFIX
PATH=\$TMPDIR/bin:\$PATH ; export PATH
LD_LIBRARY_PATH=\$TMPDIR/lib:\$LD_LIBRARY_PATH ; export LD_LIBRARY_PATH
TEXMFMAIN=\$TMPDIR/share/texmf ; export TEXMFMAIN
EOF

exit


# The following are notes for making patches
# 以下はパッチ作成のためのメモ

./0uptex.sh orig && ./0uptex.sh patch

(edit here; ここでファイル編集)
/var/tmp/ptetex3/tetex-src-3.0/texk/ptexenc/
/var/tmp/ptetex3/tetex-src-3.0/texk/makejvf/
/var/tmp/ptetex3/tetex-src-3.0/texk/web2c/uptexdir/
/var/tmp/ptetex3/tetex-src-3.0/texk/web2c/uptexdir/jmpost/
/var/tmp/ptetex3/share/texmf/


diff --exclude=\*{~,.orig} -uNr /var/tmp/ptetex3{.orig,}/tetex-src-3.0/texk/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > src.patch; \
diff ptetex3-*uptex_src*.patch src.patch | less
mv src.patch ptetex3-*uptex_src*.patch

diff --exclude=\*{~,.orig} -uNr /var/tmp/ptetex3{.orig,}/share/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > texmf.patch; \
diff ptetex3-*uptex_texmf*.patch texmf.patch | less
mv texmf.patch ptetex3-*uptex_texmf*.patch


## for utf package
diff --exclude=\*~ -uNr /var/tmp/utfsrc{.orig,}/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > utfsrc.patch; \
diff utfsrc*uptex*.patch utfsrc.patch | less
mv utfsrc.patch utfsrc_uptex-0.08.patch

## for otf package
unzip ./macro/otfstable.zip -d /var/tmp && \
mv /var/tmp/otfstable{,.orig} && \
unzip ./macro/otfstable.zip -d /var/tmp && \
patch -d /var/tmp/otfstable -p1 < otfstable*uptex*.patch
(edit here; ここでファイル編集)
/var/tmp/otfstable
diff --exclude=\*~ -uNr /var/tmp/otfstable{.orig,}/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > otfstable.patch; \
diff otfstable*uptex*.patch otfstable.patch | less
mv otfstable.patch otfstable_uptex-0.25.patch

## for updvi2tty
tar zxf $SRC_DIR/dvi2tty51.tgz -C /var/tmp && \
mv /var/tmp/dvi2tty-5.1 /var/tmp/jdvi2tty && \
patch -d /var/tmp/jdvi2tty -p1 < $SRC_DIR/dvi2tty-5.1.patch
tar zxf $SRC_DIR/dvi2tty51.tgz -C /var/tmp && \
mv /var/tmp/dvi2tty-5.1 /var/tmp/updvi2tty && \
patch -d /var/tmp/updvi2tty -p1 < $SRC_DIR/dvi2tty-5.1.patch &&
patch -d /var/tmp/updvi2tty -p1 < updvi2tty-*.patch
(edit here; ここでファイル編集)
/var/tmp/updvi2tty
diff --exclude=\*~ -uNr /var/tmp/{j,up}dvi2tty/ \
    | sed -e "s/diff .* -uNr/diff -uNr/" \
    -e 's|/var/tmp/||g' -e 's/\.000000000 +/ +/g' > updvi2tty.patch; \
diff updvi2tty-*.patch updvi2tty.patch | less
mv updvi2tty.patch updvi2tty-20090720.patch


tar zcvf uptex-0.28.tar.gz uptex-0.28
